@@ -768,6 +768,16 @@ class VariableClRsyncVer(ReadonlyVariable):
             return data[0]['PVR']
         return ""
 
+class VariableClCifsutilsVer(ReadonlyVariable):
+    """
+    Версия cifs-utils
+    """
+    def get(self):
+        data = isPkgInstalled('net-fs/cifs-utils')
+        if data:
+            return data[0]['PV']
+        return ""
+
 
 class VariableClSyncMovedSet(Variable):
     """
